spannertools.Hairpin
====================

.. abjad-lineage:: abjad.tools.spannertools.Hairpin.Hairpin

.. autoclass:: abjad.tools.spannertools.Hairpin.Hairpin

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.Hairpin.Hairpin.components
      ~abjad.tools.spannertools.Hairpin.Hairpin.descriptor
      ~abjad.tools.spannertools.Hairpin.Hairpin.direction
      ~abjad.tools.spannertools.Hairpin.Hairpin.include_rests
      ~abjad.tools.spannertools.Hairpin.Hairpin.shape_string
      ~abjad.tools.spannertools.Hairpin.Hairpin.start_dynamic
      ~abjad.tools.spannertools.Hairpin.Hairpin.stop_dynamic
      ~abjad.tools.spannertools.Hairpin.Hairpin.__contains__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__copy__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__eq__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__format__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__getitem__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__hash__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__len__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__lt__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__ne__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__repr__

Bases
-----

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.descriptor
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.direction
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.include_rests
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.shape_string
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.start_dynamic
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.stop_dynamic
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__format__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__hash__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__repr__
   :noindex:
